ColorSpace enum

Enumeration of supported color spaces.

Inheritance
Available extensions

Values

rgb8 → const ColorSpace

RGB (Red, Green, Blue) color space stored as an 32 bit int

rgb16 → const ColorSpace

RGB (Red, Green, Blue) color space stored as a 64 bit int

hsl → const ColorSpace

HSL (Hue, Saturation, Lightness) color space

oklab → const ColorSpace

Oklab color space - perceptually uniform color space

oklch → const ColorSpace

Oklch color space - cylindrical form of Oklab with lightness, chroma, and hue

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ColorSpace>
A constant List of the values in this enum, in order of their declaration.