PrismPalette class abstract
- Implemented types
Constructors
Properties
-
accent100
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
accent200
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
accent400
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
accent700
→ RayWithLuminance<
Ray> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shade0
→ RayWithLuminance<
Ray> ? -
Access tones using Material Design naming convention
no setterinherited
-
shade100
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
shade1000
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
shade200
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
shade300
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
shade400
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
shade50
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
shade500
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
shade600
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
shade700
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
shade800
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
shade900
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
shade950
→ RayWithLuminance<
Ray> ? -
no setterinherited
-
source
→ RayWithLuminance<
Ray> -
The primary color this scheme is based on
finalinherited
-
spectrum
→ Map<
RayTone, RayWithLuminance< Ray> > -
Complete tonal palette with cached luminance.
finalinherited
-
surfaceDark
→ RayWithLuminance<
Ray> -
Darker surface variant (shade700).
no setterinherited
-
surfaceLight
→ RayWithLuminance<
Ray> -
Lighter surface variant (shade100).
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tone(
RayTone tone) → RayWithLuminance< Ray> ? -
Access specific tone by RayTone enum
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited