Returns the color with inverted color values, preserving opacity.
Implementation
@override
RayOklab get inverse {
// In Oklab, inversion means inverting lightness and flipping a/b axes
return RayOklab._(
l: 1.0 - _l,
a: -_a,
b: -_b,
opacity: opacity,
);
}