RayTone enum
Values
- shade0 → const RayTone
-
const RayTone(lightnessModifier: 0.98, chromaModifier: 0.12) - shade50 → const RayTone
-
const RayTone(lightnessModifier: 0.96, chromaModifier: 0.28) - shade100 → const RayTone
-
const RayTone(lightnessModifier: 0.9, chromaModifier: 0.4) - shade200 → const RayTone
-
const RayTone(lightnessModifier: 0.79, chromaModifier: 0.6) - shade300 → const RayTone
-
const RayTone(lightnessModifier: 0.7, chromaModifier: 0.8) - shade400 → const RayTone
-
const RayTone(lightnessModifier: 0.62, chromaModifier: 0.9) - shade500 → const RayTone
-
const RayTone(lightnessModifier: 0.55, chromaModifier: 1.0) - shade600 → const RayTone
-
const RayTone(lightnessModifier: 0.5, chromaModifier: 1.0) - shade700 → const RayTone
-
const RayTone(lightnessModifier: 0.42, chromaModifier: 1.0) - shade800 → const RayTone
-
const RayTone(lightnessModifier: 0.35, chromaModifier: 1.0) - shade900 → const RayTone
-
const RayTone(lightnessModifier: 0.25, chromaModifier: 1.0) - shade950 → const RayTone
-
const RayTone(lightnessModifier: 0.15, chromaModifier: 1.1) - shade1000 → const RayTone
-
const RayTone(lightnessModifier: 0.01, chromaModifier: 1.2) - accent100 → const RayTone
-
const RayTone(lightnessModifier: 0.85, fixedChroma: 1.0, type: ToneType.accent) - accent200 → const RayTone
-
const RayTone(lightnessModifier: 0.75, fixedChroma: 1.0, type: ToneType.accent) - accent400 → const RayTone
-
const RayTone(lightnessModifier: 0.65, fixedChroma: 0.9, type: ToneType.accent) - accent700 → const RayTone
-
const RayTone(lightnessModifier: 0.42, fixedChroma: 0.8, type: ToneType.accent)
Properties
- chromaModifier → double?
-
final
- fixedChroma → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- lightness → double
-
no setter
- lightnessModifier → double
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ToneType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited