RayWithLuminanceBase typedef
Type alias for the base type used in generic contexts
Implementation
typedef RayWithLuminanceBase = RayWithLuminance;
Type alias for the base type used in generic contexts
typedef RayWithLuminanceBase = RayWithLuminance;